@@ -1,2 +1,6 @@
+"""
+PynamoDB lowest level connection
+"""
+
 from .base import Connection
 from .table import TableConnection
