@@ -1,8 +1,8 @@
 """
 Tests for the base connection class
 """
+import six
 from pynamodb.compat import CompatTestCase as TestCase
-from pynamodb.compat import patch
 from pynamodb.connection import Connection
 from pynamodb.exceptions import (
     TableError, DeleteError, UpdateError, PutError, GetError, ScanError, QueryError, TableDoesNotExist)
@@ -10,6 +10,10 @@ from pynamodb.constants import DEFAULT_REGION
 from .data import DESCRIBE_TABLE_DATA, GET_ITEM_DATA, LIST_TABLE_DATA
 from .response import HttpBadRequest, HttpOK, HttpUnavailable
 
+if six.PY3:
+    from unittest.mock import patch
+else:
+    from mock import patch
 
 PATCH_METHOD = 'botocore.operation.Operation.call'
 
@@ -279,7 +283,7 @@ class ConnectionTestCase(TestCase):
             with patch(PATCH_METHOD) as req:
                 req.return_value = HttpBadRequest(), DESCRIBE_TABLE_DATA
                 conn = Connection(self.region)
-                table = conn.describe_table(self.test_table_name)
+                conn.describe_table(self.test_table_name)
 
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpUnavailable(), None
