@@ -7,7 +7,7 @@ import six
 import copy
 from datetime import datetime
 from pynamodb.compat import CompatTestCase as TestCase
-from pynamodb.compat import patch, MagicMock, OrderedDict
+from pynamodb.compat import OrderedDict
 from pynamodb.throttle import Throttle
 from pynamodb.connection.util import pythonic
 from pynamodb.exceptions import TableError
@@ -33,10 +33,54 @@ from .data import (
     BINARY_ATTR_DATA, SERIALIZED_TABLE_DATA
 )
 
+if six.PY3:
+    from unittest.mock import patch, MagicMock
+else:
+    from mock import patch, MagicMock
 
 PATCH_METHOD = 'botocore.operation.Operation.call'
 
 
+class GamePlayerOpponentIndex(LocalSecondaryIndex):
+    class Meta:
+        read_capacity_units = 1
+        write_capacity_units = 1
+        table_name = "GamePlayerOpponentIndex"
+        host = "http://localhost:8000"
+        projection = AllProjection()
+
+    player_id = UnicodeAttribute(hash_key=True)
+    winner_id = UnicodeAttribute(range_key=True)
+
+
+class GameOpponentTimeIndex(GlobalSecondaryIndex):
+    class Meta:
+        read_capacity_units = 1
+        write_capacity_units = 1
+        table_name = "GameOpponentTimeIndex"
+        host = "http://localhost:8000"
+        projection = AllProjection()
+
+    winner_id = UnicodeAttribute(hash_key=True)
+    created_time = UnicodeAttribute(range_key=True)
+
+
+class GameModel(Model):
+    class Meta:
+        read_capacity_units = 1
+        write_capacity_units = 1
+        table_name = "GameModel"
+        host = "http://localhost:8000"
+
+    player_id = UnicodeAttribute(hash_key=True)
+    created_time = UTCDateTimeAttribute(range_key=True)
+    winner_id = UnicodeAttribute()
+    loser_id = UnicodeAttribute(null=True)
+
+    player_opponent_index = GamePlayerOpponentIndex()
+    opponent_time_index = GameOpponentTimeIndex()
+
+
 class OldStyleModel(Model):
     _table_name = 'IndexedModel'
     user_name = UnicodeAttribute(hash_key=True)
@@ -206,7 +250,7 @@ class ModelTestCase(TestCase):
 
     def assert_dict_lists_equal(self, list1, list2):
         """
-        Compares two lists of dictionariess
+        Compares two lists of dictionaries
         """
         for d1_item in list1:
             found = False
@@ -215,8 +259,10 @@ class ModelTestCase(TestCase):
                     found = True
             if not found:
                 if six.PY3:
-                    #TODO WTF python2?
+                    # TODO WTF python2?
                     raise AssertionError("Values not equal: {0} {1}".format(d1_item, list2))
+        if len(list1) != len(list2):
+            raise AssertionError("Values not equal: {0} {1}".format(list1, list2))
 
     def test_create_model(self):
         """
@@ -261,7 +307,7 @@ class ModelTestCase(TestCase):
             RegionSpecificModel.create_table(read_capacity_units=2, write_capacity_units=2)
             self.assertEqual(req.call_args[0][0].region_name, 'us-west-1')
 
-         # A table with a specified host
+        # A table with a specified host
         self.assertEqual(HostSpecificModel.Meta.host, 'http://localhost')
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpOK, MODEL_TABLE_DATA
@@ -1480,6 +1526,76 @@ class ModelTestCase(TestCase):
             }
             self.assertEqual(req.call_args[1], params)
 
+    def test_multiple_indices_share_non_key_attribute(self):
+        """
+        Models.Model
+        """
+        scope_args = {'count': 0}
+
+        def fake_dynamodb(obj, **kwargs):
+            if scope_args['count'] == 0:
+                scope_args['count'] += 1
+                return HttpBadRequest(), {}
+            else:
+                return HttpOK({}), {}
+
+        fake_db = MagicMock()
+        fake_db.side_effect = fake_dynamodb
+
+        with patch(PATCH_METHOD, new=fake_db) as req:
+            IndexedModel.create_table(read_capacity_units=2, write_capacity_units=2)
+            params = {
+                'attribute_definitions': [
+                    {'AttributeName': 'email', 'AttributeType': 'S'},
+                    {'AttributeName': 'numbers', 'AttributeType': 'NS'},
+                    {'AttributeName': 'user_name', 'AttributeType': 'S'}
+                ]
+            }
+            args = req.call_args[1]
+            self.assert_dict_lists_equal(args['attribute_definitions'], params['attribute_definitions'])
+
+        scope_args['count'] = 0
+
+        with patch(PATCH_METHOD, new=fake_db) as req:
+            GameModel.create_table()
+            params = {
+                'key_schema': [
+                    {'KeyType': 'HASH', 'AttributeName': 'player_id'},
+                    {'KeyType': 'RANGE', 'AttributeName': 'created_time'}
+                ],
+                'local_secondary_indexes': [
+                    {
+                        'KeySchema': [
+                            {'KeyType': 'HASH', 'AttributeName': 'player_id'},
+                            {'KeyType': 'RANGE', 'AttributeName': 'winner_id'}
+                        ],
+                        'IndexName': 'player_opponent_index',
+                        'Projection': {'ProjectionType': 'ALL'}
+                    }
+                ],
+                'table_name': 'GameModel',
+                'provisioned_throughput': {'WriteCapacityUnits': 1, 'ReadCapacityUnits': 1},
+                'global_secondary_indexes': [
+                    {
+                        'ProvisionedThroughput': {'WriteCapacityUnits': 1, 'ReadCapacityUnits': 1},
+                        'KeySchema': [
+                            {'KeyType': 'HASH', 'AttributeName': 'winner_id'},
+                            {'KeyType': 'RANGE', 'AttributeName': 'created_time'}
+                        ],
+                        'IndexName': 'opponent_time_index',
+                        'Projection': {'ProjectionType': 'ALL'}
+                    }
+                ],
+                'attribute_definitions': [
+                    {'AttributeName': 'created_time', 'AttributeType': 'S'},
+                    {'AttributeName': 'player_id', 'AttributeType': 'S'},
+                    {'AttributeName': 'winner_id', 'AttributeType': 'S'}
+                ]
+            }
+            args = req.call_args[1]
+            for key in ['key_schema', 'attribute_definitions', 'local_secondary_indexes', 'global_secondary_indexes']:
+                self.assert_dict_lists_equal(args[key], params[key])
+
     def test_global_index(self):
         """
         Models.GlobalSecondaryIndex
